/*

The NetUsage Project
http://netusage.mozdev.org/

Copyright (C) 2004, NetUsage Project
This extension can be freely distributed under
the terms of the Mozilla Public Licence 1.1
See the licence at http://www.mozilla.org/MPL/

---------
NetUsage ToolItem

*/

const nuISPNoUpOP = 1;
const nuISPNoUp = 2;
const nuISPRelax = 3;

const nuISPAuthPost = 1;
const nuISPAuthBasic = 2;

var nuSupportedISPs = {
'bigpond': 'Bigpond Broadband',
'netspace': 'Netspace ADSL',
'iinet': 'iiNet Bliink ADSL',
}

function nuFillISPInterface(isp) {
	switch(isp) {
	case 'bigpond':
		return {
			id: isp,
			name: nuSupportedISPs[isp],
			mode: nuISPRelax,
			url: 'https://account.bigpond.com/siteminderagent/nocert/{TIMESTAMP}/smgetcred.scc?TYPE=16777217&REALM=$SM$Toolbar&TARGET=$SM$https%3a%2f%2faccount%2ebigpond%2ecom%2fbroadband%2fusage%2ftoolbar%2ftoolbar%2edo',
			urlAuth: nuISPAuthBasic,

			usagePageUrl: 'https://telstra.com/siteminderagent/login/bdumcustlogin.fcc?TYPE=33554432&REALMOID=&GUID=&SMAUTHREASON=0&TARGET=$SM$https://telstra.com/tcoma/security/login2-sm.asp%3fform=bdumcust_,_AUTH_REDIR=https://account.bigpond.com/broadband/usage/secure/monthlyusage.do',
			usagePageAuth: nuISPAuthPost,
			usagePageAuthRealm: 'username={USERNAME}&password={PASSWORD}',

			xpVerify: '/bigpond[@version="1.1"]/usage/account',

			xpUpload: '/bigpond/usage/account/upload',
			xpDownload: '/bigpond/usage/account/download',
			xpLimit: '/bigpond/usage/account/limit'
		}
	case 'netspace':
		return {
			id: isp,
			name: nuSupportedISPs[isp],
			mode: nuISPNoUpOP,
			url: 'https://usage.netspace.net.au/usage-meter/adslusage?version=2&granularity=MONTH',
			urlAuth: nuISPAuthBasic,

			usagePageUrl: 'http://my.netspace.net.au/usage-meter/timestat0',
			usagePageAuth: nuISPAuthBasic,
			usagePageAuthRealm: 'myNetspace',

			xpVerify: '/USAGE[@VERSION="2"]/TRAFFIC',
			xpPlanName: '/USAGE/PLAN/@DESCRIPTION',

			xpStartDate: '/USAGE/@START_DATE',
			xpEndDate: '/USAGE/@END_DATE',

			xpUpload: '/USAGE/TRAFFIC[@DESCRIPTION="Normal Billable Traffic"]/DATA[@TYPE="Standard"]/@UPLOADS',
			xpDownload: '/USAGE/TRAFFIC[@DESCRIPTION="Normal Billable Traffic"]/DATA[@TYPE="Standard"]/@DOWNLOADS',
			xpLimit: '/USAGE/PLAN/LIMIT[@NAME="Standard"]/@MEGABYTES',

			xpUploadP: '/USAGE/TRAFFIC[@DESCRIPTION="Normal Billable Traffic"]/DATA[@TYPE="Peak"]/@UPLOADS',
			xpDownloadP: '/USAGE/TRAFFIC[@DESCRIPTION="Normal Billable Traffic"]/DATA[@TYPE="Peak"]/@DOWNLOADS',
			xpLimitP: '/USAGE/PLAN/LIMIT[@NAME="Peak"]/@MEGABYTES',
			xpUploadPO: '/USAGE/TRAFFIC[@DESCRIPTION="Normal Billable Traffic"]/DATA[@TYPE="Off Peak"]/@UPLOADS',
			xpDownloadPO: '/USAGE/TRAFFIC[@DESCRIPTION="Normal Billable Traffic"]/DATA[@TYPE="Off Peak"]/@DOWNLOADS',
			xpLimitPO: '/USAGE/PLAN/LIMIT[@NAME="Off Peak"]/@MEGABYTES'
		}
	case 'iinet':
		return {
			id: isp,
			name: nuSupportedISPs[isp],
			mode: nuISPNoUpOP,
			url: 'https://toolbox.iinet.net.au/cgi-bin/volumegraphs.cgi?action=login&username={USERNAME}&password={PASSWORD}&nocache={TIMESTAMP}',
			urlAuth: nuISPAuthPost,

			usagePageUrl: 'https://toolbox.iinet.net.au/cgi-bin/volumegraphs.cgi',
			usagePageAuth: nuISPAuthPost,
			usagePageAuthRealm: 'action=login&username={USERNAME}&password={PASSWORD}',

			regexp1: /Your quota is : ([0-9]+) MB Peak time, ([0-9]+) MB bliinktime[^`]+?volumegraphs\.cgi\?action=showday.+?>([0-9]{2}-[0-9]{2}-[0-9]{4})<\/A>[^`]+?volumegraphs\.cgi\?action=showday.+?>([0-9]{2}-[0-9]{2}-[0-9]{4})<\/A><\/TD>[\n\r ]+<TD>[^<]+<\/TD>[\n\r ]+<TD>[^<]+<\/TD>[\n\r ]+<TD>[^<]+<\/TD>[\n\r ]+<TD>[^<]+<\/TD>[\n\r ]+<TD>[^<]+<\/TD>[\n\r ]+<TD>[^<]+<\/TD>[\n\r ]+<\/TR>[\n\r ]+<TR ALIGN=right BGCOLOR=#ebebff>[\n\r ]+<TD>&nbsp;<\/TD>[\n\r ]+<TD ALIGN=left><B>Total<\/B><\/TD>[\n\r ]+<TD><B>&nbsp;<\/TD>[\n\r ]+<TD><B>([\.0-9]+)<\/B><\/TD>[\n\r ]+<TD><B>([\.0-9]+)<\/B><\/TD>[\n\r ]+<TD><B>([\.0-9]+)<\/B><\/TD>/,

			iPlanName: 0,

			iStartDate: 3,
			iEndDate: 4,

			iUpload: 0,
			iDownload: 0,
			iLimit: 0,

			iUploadP: 0,
			iDownloadP: 5,
			iLimitP: 1,
			iUploadPO: 0,
			iDownloadPO: 7,
			iLimitPO: 2
		}

	}
	return null;

}